#include <boost/bloom/filter.hpp>
#include <string>
#include <iostream>
#include <boost/hash2/fnv1a.hpp>
#include <boost/hash2/hash_append.hpp>
#include <boost/hash2/get_integral_result.hpp>

template<class T, class H> class MyHash
{
public:

  std::size_t operator()( T const& v ) const
  {
    H h;
    boost::hash2::hash_append( h, {}, v );
    return boost::hash2::get_integral_result<std::size_t>( h );
  }
};

int main()
{
  using hasher = MyHash<std::string, boost::hash2::fnv1a_64>;
  using filter = boost::bloom::filter<std::string, 5, boost::bloom::block<unsigned char, 1>, 0, hasher>;

  filter f(1000000);

  f.insert("hello");
  f.insert("Boost");

  std::cout << "hello: " << (f.may_contain("hello") == true) << std::endl;
  std::cout << "Boost: " << (f.may_contain("Boost") == true) << std::endl;
  std::cout << "bye: " << (f.may_contain("bye") == true) << std::endl;
}